@@ -6,7 +6,7 @@ use LWP::UserAgent;
 use JSON qw();
 use namespace::autoclean;
 
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 extends 'HTML::FormHandler::Field';
 
@@ -123,6 +123,15 @@ Example L<Catalyst> controller:
         ## Redisplay form and ask to try again.
     }
 
+Example L<Catalyst> config:
+
+		__PACKAGE__->config(
+			'HTML::FormHandlerX::Field::noCAPTCHA' => {
+				site_key   => '[YOUR SITE KEY]',
+				secret_key => '[YOUR SECRET KEY]-IaHaF3jRN4j340MkGLNw6tcDu',
+			},
+		);
+
 =head1 FIELD OPTIONS
 
 Support for the following field options, over what is inherited from
